#ifndef NT2_INCLUDE_FUNCTIONS_DEGREE_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_DEGREE_HPP_INCLUDED

#include <nt2/polynom/include/functions/degree.hpp>

#endif
